@@ -183,6 +183,7 @@ sub import {
             !$SkipInstall
             and (
                 $CheckOnly
+                or ($mandatory and $ENV{PERL5_CPANPLUS_IS_RUNNING})
                 or _prompt(
                     qq{==> Auto-install the }
                       . ( @required / 2 )
@@ -987,7 +988,7 @@ L<CPANPLUS>
 
 Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
